@@ -1,8 +1,5 @@
-# check_env_variables.py
-
 import os
 import sys
-from .service import HelloWindowService
 
 def check_environment_variables():
     required_variables = [
